@@ -152,7 +152,6 @@ environ_filter += [
 	"BINPKG_COMPRESS", "BINPKG_COMPRESS_FLAGS",
 	"CLEAN_DELAY", "COLLISION_IGNORE",
 	"CONFIG_PROTECT", "CONFIG_PROTECT_MASK",
-	"DCO_SIGNED_OFF_BY",
 	"EGENCACHE_DEFAULT_OPTS", "EMERGE_DEFAULT_OPTS",
 	"EMERGE_LOG_DIR",
 	"EMERGE_WARNING_DELAY",
@@ -182,6 +181,7 @@ environ_filter += [
 	"RESUMECOMMAND", "RESUMECOMMAND_FTP",
 	"RESUMECOMMAND_HTTP", "RESUMECOMMAND_HTTPS",
 	"RESUMECOMMAND_RSYNC", "RESUMECOMMAND_SFTP",
+	"SIGNED_OFF_BY",
 	"UNINSTALL_IGNORE", "USE_EXPAND_HIDDEN", "USE_ORDER",
 	"__PORTAGE_HELPER"
 ]
