@@ -1,6 +1,7 @@
-# Copyright 2010-2015 Gentoo Foundation
+# Copyright 2010-2019 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
+import bz2
 from itertools import permutations
 import fnmatch
 import sys
@@ -98,6 +99,7 @@ class ResolverPlayground(object):
 				"install",
 				"ln",
 				"mkdir",
+				"mkfifo",
 				"mktemp",
 				"mv",
 				"readlink",
@@ -332,6 +334,17 @@ class ResolverPlayground(object):
 				with open(os.path.join(vdb_pkg_dir, k), "w") as f:
 					f.write("%s\n" % v)
 
+			ebuild_path = os.path.join(vdb_pkg_dir, a.cpv.split("/")[1] + ".ebuild")
+			with open(ebuild_path, "w") as f:
+				f.write('EAPI="%s"\n' % metadata.pop('EAPI', '0'))
+				for k, v in metadata.items():
+					f.write('%s="%s"\n' % (k, v))
+
+			env_path = os.path.join(vdb_pkg_dir, 'environment.bz2')
+			with bz2.BZ2File(env_path, mode='w') as f:
+				with open(ebuild_path, 'rb') as inputfile:
+					f.write(inputfile.read())
+
 	def _create_profile(self, ebuilds, installed, profile, repo_configs, user_config, sets):
 
 		user_config_dir = os.path.join(self.eroot, USER_CONFIG_PATH)
@@ -399,7 +412,7 @@ class ResolverPlayground(object):
 					f.write("masters =\n")
 
 			if repo == "test_repo":
-				#Create a minimal profile in /usr/portage
+				#Create a minimal profile in /var/db/repos/gentoo
 				sub_profile_dir = os.path.join(profile_dir, "default", "linux", "x86", "test_profile")
 				os.makedirs(sub_profile_dir)
 
